Fides Admin UI - Systems
Description: Generated from FidesUI template

## Configure your system

Configuration Settings

### Describe your system

By providing a small amount of additional context for each system we can make reporting and understanding our tech stack much easier for everyone from engineering to legal teams. So let’s do this now.
System name
System key
System description
System Type
System Tags
Select...

System dependencies
Select...

Data responsibility title
Select...

Administrating department
Geographic location
Select...

Joint controller
Name
Address
Email
Phone
Data protection impact assessment
Is required
Yes No